==> firebase_node-0.0.1.tar.gz: lib/src/admin/admin.dart <==
import 'package:node_interop/https.dart';

import '../utils/js.dart';
import '../utils/utils.dart';
import 'app.dart';
import 'auth.dart';
import 'credential.dart';
import 'database.dart';
import 'firestore.dart';
import 'instance_id.dart';
import 'interop/admin_interop.dart' as interop;
import 'interop/admin_interop.dart' as admin;
import 'machine_learning.dart';
import 'messaging.dart';
import 'project_management.dart';
import 'remote_config.dart';

export 'interop/admin_interop.dart'
    show SDK_VERSION, ServiceAccount, FirebaseArrayIndexError, FirebaseError;

/// Instance of admin.credential
const credential = CredentialBuilder();

/// A (read-only) array of all the initialized Apps.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase#.apps>.
List<App> get apps => admin.apps
    // explicitly typing the param as dynamic to work-around
    // https://github.com/dart-lang/sdk/issues/33537
    // ignore: unnecessary_lambdas
    .map((dynamic e) => App.getInstance(e))
    .toList();

/// Retrieves an instance of an [App].
///
/// With no arguments, this returns the default App. With a single
/// string argument, it returns the named App.
///
/// This function throws an exception if the app you are trying
/// to access does not exist.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.app>.
App app([String name]) {
  var jsObject = (name != null) ? admin.app(name) : admin.app();

  return App.getInstance(jsObject);
}

/// Gets the [Auth] object for the default App or a given App.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.auth>.
Auth auth([App app]) {
  var jsObject = (app != null) ? admin.auth(app.jsObject) : admin.auth();

  return Auth.getInstance(jsObject);
}

/// Accesses the [Database] service for the default App or a given app.
///
/// The database is also a namespace that can be used to access
/// global constants and methods associated with the database service.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.database>.
Database database([App app]) {
  var jsObject =
      (app != null) ? admin.database(app.jsObject) : admin.database();

  return Database.getInstance(jsObject);
}

/// Accesses the [Firestore] service for the default App or a given app.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.firestore>.
Firestore firestore([App app]) {
  var jsObject =
      (app != null) ? admin.firestore(app.jsObject) : admin.firestore();

  return Firestore.getInstance(jsObject);
}

/// Creates (and initializes) a Firebase App with API key, auth domain,
/// database URL and storage bucket.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase#.initializeApp>.
App initializeApp({
  String name = '[DEFAULT]',
  AppOptions options,
}) =>
    App.getInstance(admin.initializeApp(options.jsObject, name));

/// Gets the InstanceId service for the current app.
InstanceId instanceId([App app]) {
  var jsObject =
      (app != null) ? admin.instanceId(app.jsObject) : admin.instanceId();

  return InstanceId.getInstance(jsObject);
}

MachineLearning machineLearning([App app]) {
  var jsObject = (app != null)
      ? admin.machineLearning(app.jsObject)
      : admin.machineLearning();

  return MachineLearning.getInstance(jsObject);
}

Messaging messaging([App app]) {
  var jsObject =
      (app != null) ? admin.messaging(app.jsObject) : admin.messaging();

  return Messaging.getInstance(jsObject);
}

ProjectManagement projectManagement([App app]) {
  var jsObject = (app != null)
      ? admin.projectManagement(app.jsObject)
      : admin.projectManagement();

  return ProjectManagement.getInstance(jsObject);
}

RemoteConfig remoteConfig([App app]) {
  var jsObject =
      (app != null) ? admin.remoteConfig(app.jsObject) : admin.remoteConfig();

  return RemoteConfig.getInstance(jsObject);
}

/// The namespace for all the [Storage] functionality.
///
/// The returned service is initialized with a particular app which contains
/// the project's storage location, or uses the default app if none is provided.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.storage>.

class AppOptions extends JsObjectWrapper<interop.AppOptionsJsImpl> {
  static final _expando = Expando<AppOptions>();

  factory AppOptions({
    Credential credential,
    Map<String, dynamic> databaseAuthVariableOverride,
    String databaseUrl,
    String serviceAccountId,
    String storageBucket,
    String projectId,
    HttpAgent httpAgent,
  }) =>
      AppOptions.getInstance(interop.AppOptionsJsImpl(
        credential: credential.jsObject,
        databaseAuthVariableOverride: jsify(databaseAuthVariableOverride),
        databaseURL: databaseUrl,
        serviceAccountId: serviceAccountId,
        storageBucket: storageBucket,
        projectId: projectId,
        httpAgent: httpAgent,
      ));

  factory AppOptions.getInstance(interop.AppOptionsJsImpl jsObject) {
    if (jsObject == null) return null;
    return _expando[jsObject] ??= AppOptions._fromJsObject(jsObject);
  }

  AppOptions._fromJsObject(interop.AppOptionsJsImpl jsObject)
      : super.fromJsObject(jsObject);

  Credential get credential => Credential.getInstance(jsObject.credential);
  set credential(Credential v) => jsObject.credential = v.jsObject;

  Map<String, dynamic> get databaseAuthVariableOverride =>
      dartify(jsObject.databaseAuthVariableOverride);
  set databaseAuthVariableOverride(Map<String, dynamic> v) =>
      jsObject.databaseAuthVariableOverride = jsify(v);

  String get databaseUrl => jsObject.databaseURL;
  set databaseUrl(String v) => jsObject.databaseURL = v;

  HttpAgent get httpAgent => jsObject.httpAgent;
  set httpAgent(HttpAgent v) => jsObject.httpAgent = v;

  String get projectId => jsObject.projectId;
  set projectId(String v) => jsObject.projectId = v;

  String get serviceAccountId => jsObject.serviceAccountId;
  set serviceAccountId(String v) => jsObject.serviceAccountId = v;

  String get storageBucket => jsObject.storageBucket;
  set storageBucket(String v) => jsObject.storageBucket = v;
}

==> firebase_node-0.0.2.tar.gz: lib/src/admin/admin.dart <==
import 'package:node_interop/https.dart';

import '../utils/js.dart';
import '../utils/utils.dart';
import 'app.dart';
import 'auth.dart';
import 'credential.dart';
import 'database.dart';
import 'firestore.dart';
import 'instance_id.dart';
import 'interop/admin_interop.dart' as interop;
import 'interop/admin_interop.dart' as admin;
import 'machine_learning.dart';
import 'messaging.dart';
import 'project_management.dart';
import 'remote_config.dart';

export 'interop/admin_interop.dart'
    show SDK_VERSION, ServiceAccount, FirebaseArrayIndexError, FirebaseError;

/// Instance of admin.credential
const credential = CredentialBuilder();

/// A (read-only) array of all the initialized Apps.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase#.apps>.
List<App> get apps => admin.apps
    // explicitly typing the param as dynamic to work-around
    // https://github.com/dart-lang/sdk/issues/33537
    // ignore: unnecessary_lambdas
    .map((dynamic e) => App.getInstance(e))
    .toList();

/// Retrieves an instance of an [App].
///
/// With no arguments, this returns the default App. With a single
/// string argument, it returns the named App.
///
/// This function throws an exception if the app you are trying
/// to access does not exist.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.app>.
App app([String name]) {
  var jsObject = (name != null) ? admin.app(name) : admin.app();

  return App.getInstance(jsObject);
}

/// Gets the [Auth] object for the default App or a given App.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.auth>.
Auth auth([App app]) {
  var jsObject = (app != null) ? admin.auth(app.jsObject) : admin.auth();

  return Auth.getInstance(jsObject);
}

/// Accesses the [Database] service for the default App or a given app.
///
/// The database is also a namespace that can be used to access
/// global constants and methods associated with the database service.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.database>.
Database database([App app]) {
  var jsObject =
      (app != null) ? admin.database(app.jsObject) : admin.database();

  return Database.getInstance(jsObject);
}

/// Accesses the [Firestore] service for the default App or a given app.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.firestore>.
Firestore firestore([App app]) {
  var jsObject =
      (app != null) ? admin.firestore(app.jsObject) : admin.firestore();

  return Firestore.getInstance(jsObject);
}

/// Creates (and initializes) a Firebase App with API key, auth domain,
/// database URL and storage bucket.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase#.initializeApp>.
App initializeApp({
  String name = '[DEFAULT]',
  AppOptions options,
}) =>
    App.getInstance(admin.initializeApp(
      options?.jsObject ??
          AppOptions.getInstance(interop.AppOptionsJsImpl()).jsObject,
      name,
    ));

/// Gets the InstanceId service for the current app.
InstanceId instanceId([App app]) {
  var jsObject =
      (app != null) ? admin.instanceId(app.jsObject) : admin.instanceId();

  return InstanceId.getInstance(jsObject);
}

MachineLearning machineLearning([App app]) {
  var jsObject = (app != null)
      ? admin.machineLearning(app.jsObject)
      : admin.machineLearning();

  return MachineLearning.getInstance(jsObject);
}

Messaging messaging([App app]) {
  var jsObject =
      (app != null) ? admin.messaging(app.jsObject) : admin.messaging();

  return Messaging.getInstance(jsObject);
}

ProjectManagement projectManagement([App app]) {
  var jsObject = (app != null)
      ? admin.projectManagement(app.jsObject)
      : admin.projectManagement();

  return ProjectManagement.getInstance(jsObject);
}

RemoteConfig remoteConfig([App app]) {
  var jsObject =
      (app != null) ? admin.remoteConfig(app.jsObject) : admin.remoteConfig();

  return RemoteConfig.getInstance(jsObject);
}

/// The namespace for all the [Storage] functionality.
///
/// The returned service is initialized with a particular app which contains
/// the project's storage location, or uses the default app if none is provided.
///
/// See: <https://firebase.google.com/docs/reference/js/firebase.storage>.

class AppOptions extends JsObjectWrapper<interop.AppOptionsJsImpl> {
  static final _expando = Expando<AppOptions>();

  factory AppOptions({
    Credential credential,
    Map<String, dynamic> databaseAuthVariableOverride,
    String databaseUrl,
    String serviceAccountId,
    String storageBucket,
    String projectId,
    HttpAgent httpAgent,
  }) =>
      AppOptions.getInstance(interop.AppOptionsJsImpl(
        credential: credential?.jsObject,
        databaseAuthVariableOverride: jsify(databaseAuthVariableOverride),
        databaseURL: databaseUrl,
        serviceAccountId: serviceAccountId,
        storageBucket: storageBucket,
        projectId: projectId,
        httpAgent: httpAgent,
      ));

  factory AppOptions.getInstance(interop.AppOptionsJsImpl jsObject) {
    if (jsObject == null) return null;
    return _expando[jsObject] ??= AppOptions._fromJsObject(jsObject);
  }

  AppOptions._fromJsObject(interop.AppOptionsJsImpl jsObject)
      : super.fromJsObject(jsObject);

  Credential get credential => Credential.getInstance(jsObject.credential);
  set credential(Credential v) => jsObject.credential = v.jsObject;

  Map<String, dynamic> get databaseAuthVariableOverride =>
      dartify(jsObject.databaseAuthVariableOverride);
  set databaseAuthVariableOverride(Map<String, dynamic> v) =>
      jsObject.databaseAuthVariableOverride = jsify(v);

  String get databaseUrl => jsObject.databaseURL;
  set databaseUrl(String v) => jsObject.databaseURL = v;

  HttpAgent get httpAgent => jsObject.httpAgent;
  set httpAgent(HttpAgent v) => jsObject.httpAgent = v;

  String get projectId => jsObject.projectId;
  set projectId(String v) => jsObject.projectId = v;

  String get serviceAccountId => jsObject.serviceAccountId;
  set serviceAccountId(String v) => jsObject.serviceAccountId = v;

  String get storageBucket => jsObject.storageBucket;
  set storageBucket(String v) => jsObject.storageBucket = v;
}
